/*
 * JBoss, Home of Professional Open Source
 * Copyright 2008, Red Hat Middleware LLC, and individual contributors
 * by the @authors tag. See the copyright.txt in the distribution for a
 * full listing of individual contributors.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.jboss.metatype.api.values;

import java.math.BigDecimal;
import java.math.BigInteger;
import java.util.Comparator;
import java.util.Date;

import org.jboss.metatype.api.types.Name;
import org.jboss.metatype.api.types.SimpleMetaType;

/**
 * A Comparator for SimpleValues.
 * 
 * @author Scott.Stark@jboss.org
 * @version $Revision:$
 */
public class SimpleValueComparator
   implements Comparator<SimpleValue>
{
   public int compare(SimpleValue o1, SimpleValue o2)
   {
      int compare = -1;
      if(o1.getMetaType() == SimpleMetaType.BIGINTEGER && o2.getMetaType() == SimpleMetaType.BIGINTEGER)
      {
         BigInteger v1 = BigInteger.class.cast(o1.getValue());
         BigInteger v2 = BigInteger.class.cast(o2.getValue());
         compare = v1.compareTo(v2);
      }
      else if(o1.getMetaType() == SimpleMetaType.BIGDECIMAL && o2.getMetaType() == SimpleMetaType.BIGDECIMAL)
      {
         BigDecimal v1 = BigDecimal.class.cast(o1.getValue());
         BigDecimal v2 = BigDecimal.class.cast(o2.getValue());
         compare = v1.compareTo(v2);
      }
      else if(o1.getMetaType() == SimpleMetaType.BOOLEAN && o2.getMetaType() == SimpleMetaType.BOOLEAN)
      {
         Boolean v1 = Boolean.class.cast(o1.getValue());
         Boolean v2 = Boolean.class.cast(o2.getValue());
         compare = v1.compareTo(v2);
      }
      else if(o1.getMetaType() == SimpleMetaType.BYTE && o2.getMetaType() == SimpleMetaType.BYTE)
      {
         Byte v1 = Byte.class.cast(o1.getValue());
         Byte v2 = Byte.class.cast(o2.getValue());
         compare = v1.compareTo(v2);
      }
      else if(o1.getMetaType() == SimpleMetaType.CHARACTER && o2.getMetaType() == SimpleMetaType.CHARACTER)
      {
         Character v1 = Character.class.cast(o1.getValue());
         Character v2 = Character.class.cast(o2.getValue());
         compare = v1.compareTo(v2);
      }
      else if(o1.getMetaType() == SimpleMetaType.DATE && o2.getMetaType() == SimpleMetaType.DATE)
      {
         Date v1 = Date.class.cast(o1.getValue());
         Date v2 = Date.class.cast(o2.getValue());
         compare = v1.compareTo(v2);
      }
      else if(o1.getMetaType() == SimpleMetaType.DOUBLE && o2.getMetaType() == SimpleMetaType.DOUBLE)
      {
         Double v1 = Double.class.cast(o1.getValue());
         Double v2 = Double.class.cast(o2.getValue());
         compare = v1.compareTo(v2);
      }
      else if(o1.getMetaType() == SimpleMetaType.FLOAT && o2.getMetaType() == SimpleMetaType.FLOAT)
      {
         Float v1 = Float.class.cast(o1.getValue());
         Float v2 = Float.class.cast(o2.getValue());
         compare = v1.compareTo(v2);
      }
      else if(o1.getMetaType() == SimpleMetaType.INTEGER && o2.getMetaType() == SimpleMetaType.INTEGER)
      {
         Integer v1 = Integer.class.cast(o1.getValue());
         Integer v2 = Integer.class.cast(o2.getValue());
         compare = v1.compareTo(v2);
      }
      else if(o1.getMetaType() == SimpleMetaType.LONG && o2.getMetaType() == SimpleMetaType.LONG)
      {
         Long v1 = Long.class.cast(o1.getValue());
         Long v2 = Long.class.cast(o2.getValue());
         compare = v1.compareTo(v2);
      }
      else if(o1.getMetaType() == SimpleMetaType.SHORT && o2.getMetaType() == SimpleMetaType.SHORT)
      {
         Short v1 = Short.class.cast(o1.getValue());
         Short v2 = Short.class.cast(o2.getValue());
         compare = v1.compareTo(v2);
      }
      else if(o1.getMetaType() == SimpleMetaType.STRING && o2.getMetaType() == SimpleMetaType.STRING)
      {
         String v1 = String.class.cast(o1.getValue());
         String v2 = String.class.cast(o2.getValue());
         compare = v1.compareTo(v2);
      }
      else if(o1.getMetaType() == SimpleMetaType.NAMEDOBJECT && o2.getMetaType() == SimpleMetaType.NAMEDOBJECT)
      {
         Name v1 = Name.class.cast(o1.getValue());
         Name v2 = Name.class.cast(o2.getValue());
         compare = v1.compareTo(v2);
      }
      else if(o1.getMetaType() == SimpleMetaType.VOID && o2.getMetaType() == SimpleMetaType.VOID)
      {
         compare = 0;
      }

      return compare;
   }
}
